@@ -2,12 +2,11 @@
 import argparse
 import logging
 import os
+import subprocess
 import sys
 import webbrowser
-import time
+from typing import Optional
 
-import eventlet  # type: ignore
-import requests
 from pytest_commander import api
 
 LOGGER = logging.getLogger(__name__)
@@ -22,7 +21,7 @@ def main():
     if args.port == 0:
         sys.exit("Binding to port 0 is not currently supported.")
 
-    log_level = logging.DEBUG if args.debug else logging.CRITICAL
+    log_level = logging.DEBUG if args.debug else logging.WARNING
     logging.basicConfig(level=log_level)
 
     app, socketio, test_runner = api.build_app(args.directory, args.watch)
@@ -32,10 +31,10 @@ def main():
         # According to the eventlet concurrency model, this will not be started
         # as a background task until the socketio server has started and
         # co-operatively yields control.
-        socketio.start_background_task(open_webbrowser, address)
+        socketio.start_background_task(open_webbrowser, address, args.browser)
 
     with test_runner:
-        socketio.run(app, host=args.host, port=args.port, debug=args.debug)
+        socketio.run(app, host=args.host, port=args.port)
 
 
 def display_host(host: str) -> str:
@@ -52,7 +51,7 @@ def parse_args() -> argparse.Namespace:
     parser.add_argument(
         "directory",
         nargs="?",
-        default=".",
+        default=os.getcwd(),
         help=f"Directory to find PyTest test modules, defaults to cwd ({os.getcwd()})",
     )
     parser.add_argument(
@@ -91,13 +90,24 @@ def parse_args() -> argparse.Namespace:
             "select 'disabled'."
         ),
     )
+    parser.add_argument(
+        "-b",
+        "--browser",
+        help=(
+            "Specify web browser executable to open the UI in. If not specified, "
+            "the system's default browser will be used."
+        ),
+    )
 
     return parser.parse_args()
 
 
-def open_webbrowser(address: str):
+def open_webbrowser(address: str, browser: Optional[str]):
     LOGGER.critical("View in your browser at %s", address)
-    webbrowser.open(address)
+    if browser:
+        subprocess.Popen([browser, address])
+    else:
+        webbrowser.open(address)
 
 
 if __name__ == "__main__":
