@@ -40,8 +40,8 @@ class PyTestRunner:
         socketio: flask_socketio.SocketIO,
         watch_mode: str,
     ):
-        self._directory = directory
-        self.result_tree = _init_result_tree(directory, watch_mode)
+        self._directory = os.path.abspath(directory)
+        self.result_tree = _init_result_tree(self._directory, watch_mode)
         self._socketio = socketio
         self._branch_schema = result_tree.BranchNodeSchema()
         self._leaf_schema = result_tree.LeafNodeSchema()
@@ -57,7 +57,8 @@ class PyTestRunner:
         if self._watch_mode != "disabled":
             queue = multiprocessing.Queue()
             self._watchdog_proc = multiprocessing.Process(
-                target=watcher.watch_filesystem, args=(self._directory, queue)
+                target=watcher.watch_filesystem,
+                args=(self._directory, queue, LOGGER.getEffectiveLevel()),
             )
             self._watchdog_proc.start()
             assert queue.get() == watcher.READY
@@ -152,7 +153,11 @@ class PyTestRunner:
         result_node = self._node_index[nodeid.Nodeid.from_string(report.nodeid)]
         assert isinstance(result_node, result_tree.LeafNode)
         result_node.status = result_tree.TestState(report.outcome)
-        result_node.longrepr = report.longrepr
+
+        if report.longrepr is None:
+            result_node.longrepr = None
+        else:
+            result_node.longrepr = str(report.longrepr)
 
     def _get_parent_node(
         self, child_nodeid: nodeid.Nodeid
